# Doesn't require any BIOS/copyrighted material, so it can go in core.

Name:           fceux
Version:        2.2.3
Release:        %mkrel 6
Summary:        A cross platform, NTSC and PAL Famicom/NES emulator
Group:          Emulators
License:        GPLv2+
URL:            http://fceux.com/
Source:         http://downloads.sourceforge.net/fceultra/%{name}-%{version}.src.tar.gz
Patch0:         fceux-2.2.2-mga-desktop.patch
# Fix building with python3 scons
# Patch from ArchLinux
Patch1:         fceux-2.2.3-scons-python3.patch

BuildRequires:  lua5.1-devel
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  scons

%description
FCEUX is a Nintendo Entertainment System (NES), Famicom, and Famicom
Disk System (FDS) emulator. It supports both PAL (European) and NTSC
(USA/JPN) modes.

The FCEUX concept is that of an "all in one" emulator that offers accurate
emulation and the best options for both casual play and a variety of more
advanced emulator functions. For pro users, FCEUX offers tools for debugging,
rom-hacking, map making, Tool-assisted movies, and Lua scripting

%files
%doc Authors changelog.txt COPYING NewPPUtests.txt README-SDL TODO-SDL
%doc documentation/{cheat.html,faq,todo,TODO-PROJECT,Videolog.txt}
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/32x32/apps/%{name}.png
%{_mandir}/man6/%{name}.6*

#----------------------------------------------------------------------------

%package        net-server
Summary:        Server for the FCEUX emulator

%description    net-server
FCEUX clients can connect to this server and play multiplayer NES games over
the network.

%files          net-server
%doc fceux-server/{AUTHORS,ChangeLog,COPYING,README}
%{_bindir}/%{name}-net-server
%config(noreplace) %{_sysconfdir}/%{name}-server.conf
%{_mandir}/man6/%{name}-net-server.6*

#----------------------------------------------------------------------------

%prep
%setup -q
%autopatch -p1

# Remove bundled LUA and minizip libraries
rm -rf src/lua
rm -rf src/utils/unzip.*

# Fix end-of-line-encoding
sed -i 's/\r//' changelog.txt NewPPUtests.txt \
  documentation/Videolog.txt \
  fceux-server/{AUTHORS,ChangeLog,README}

%build
%set_build_flags
%scons \
  RELEASE=1 \
  SYSTEM_LUA=1 \
  SYSTEM_MINIZIP=1

%install
# Install binary files
install -d %{buildroot}%{_bindir}
install -p -m 755 bin/fceux %{buildroot}%{_bindir}
install -p -m 755 bin/fceux-net-server %{buildroot}%{_bindir}

# Install data
install -d %{buildroot}%{_datadir}/%{name}
cp -pR output/{palettes,luaScripts} %{buildroot}%{_datadir}/%{name}
install -p -m 644 bin/auxlib.lua %{buildroot}%{_datadir}/%{name}/luaScripts/

# Install icon
install -D -p -m 644 %{name}.png \
  %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png

# Install desktop file
install -D -p -m 644 %{name}.desktop \
  %{buildroot}%{_datadir}/applications/%{name}.desktop

# Install man pages
install -d %{buildroot}%{_mandir}/man6
install -p -m 644 documentation/fceux.6 \
  %{buildroot}%{_mandir}/man6/
install -p -m 644 documentation/fceux-net-server.6 \
  %{buildroot}%{_mandir}/man6/

# Install config file
install -D -p -m 644 fceux-server/fceux-server.conf \
  %{buildroot}%{_sysconfdir}/%{name}-server.conf


%changelog
* Tue Nov 03 2020 akien <akien> 2.2.3-6.mga8
+ Revision: 1642034
- Rebuild in core as it doesn't require tainted material to work

* Fri Feb 21 2020 umeabot <umeabot> 2.2.3-5.mga8.tainted
+ Revision: 1548869
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Tue Sep 17 2019 daviddavid <daviddavid> 2.2.3-4.mga8.tainted
+ Revision: 1442743
- switch to python3-scons

* Fri Apr 05 2019 daviddavid <daviddavid> 2.2.3-3.mga7.tainted
+ Revision: 1385978
- switch to Python2 scons support

* Thu Sep 20 2018 umeabot <umeabot> 2.2.3-2.mga7.tainted
+ Revision: 1278220
- Mageia 7 Mass Rebuild

* Fri Jul 29 2016 akien <akien> 2.2.3-1.mga6.tainted
+ Revision: 1043888
- Turn on RELEASE build
- Version 2.2.3

* Wed Feb 24 2016 daviddavid <daviddavid> 2.2.2-5.mga6.tainted
+ Revision: 977867
- rebuild for Mageia 6

* Mon Feb 16 2015 oden <oden> 2.2.2-4.mga5.tainted
+ Revision: 815142
- rebuilt for libgd-2.1.1

* Wed Oct 15 2014 umeabot <umeabot> 2.2.2-3.mga5.tainted
+ Revision: 747830
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.2.2-2.mga5.tainted
+ Revision: 679106
- Mageia 5 Mass Rebuild

* Sat Jun 14 2014 akien <akien> 2.2.2-1.mga5.tainted
+ Revision: 636146
- Update %%description based on the upstream website
- Remove useless stuff from %%prep section
- Add a patch to clean the desktop file
- imported package fceux from Fedora

